@@ -1,4 +1,4 @@
-from typing import Dict, List
+from typing import Dict, List, Optional
 import json
 from hein_robots.robotics import Location
 from hein_robots.grids import LocationGroup
@@ -20,9 +20,14 @@ class KinovaSequence(LocationGroup):
 
             return locations
 
-    def __init__(self, sequence_json_file: str):
+    def __init__(self, sequence_json_file: str, location_names: Optional[List[str]] = None):
         self.locations = self.parse_sequence_file(sequence_json_file)
 
+        if location_names is not None:
+            for name in location_names:
+                if name not in self.locations:
+                    raise KinovaSequenceError(f'Location "{name}" not found in Kinova sequence file: {sequence_json_file}')
+
     def __len__(self):
         return len(self.locations)
 
@@ -31,3 +36,7 @@ class KinovaSequence(LocationGroup):
 
     def indexes(self) -> List[str]:
         return list(self.locations.keys())
+
+
+class KinovaSequenceError(Exception):
+    pass
