@@ -1,4 +1,4 @@
-from typing import Dict, List, Tuple
+from typing import Dict, List, Tuple, Optional
 from collections import OrderedDict
 import re
 import math
@@ -33,8 +33,13 @@ class URScriptSequence(LocationGroup):
 
         return locations, joints
 
-    def __init__(self, sequence_json_file: str):
-        self.locations, self.joints = self.parse_sequence_file(sequence_json_file)
+    def __init__(self, urscript_file: str, location_names: Optional[List[str]] = None):
+        self.locations, self.joints = self.parse_sequence_file(urscript_file)
+
+        if location_names is not None:
+            for name in location_names:
+                if name not in self.locations:
+                    raise URScriptSequenceError(f'Location "{name}" not found in URScript file: {urscript_file}')
 
     def __len__(self):
         return len(self.locations)
@@ -44,3 +49,7 @@ class URScriptSequence(LocationGroup):
 
     def indexes(self) -> List[str]:
         return list(self.locations.keys())
+
+
+class URScriptSequenceError(Exception):
+    pass
